@@ -6,11 +6,13 @@
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
  ****************************************************************************** */
+// Copyright (c) 2021 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 import { isRequired } from './utils';
 
 describe('Utils', () => {
-  test('Test Utils isRequired Returns Error', () => {
+  test('Utils isRequired Returns Error', () => {
     expect(() => isRequired('testParam')).toThrow(Error);
   });
 });
