@@ -1,8 +1,14 @@
 "use strict";
+
 const redis = require("redis"),
+	// @ts-ignore
 	util = require("util"),
 	ResultSet = require("./resultSet");
 
+/**
+ * @typedef {import('ioredis') | redis.RedisClient} RedisClient
+ */
+
 /**
  * RedisGraph client
  */
@@ -12,9 +18,9 @@ class Graph {
       * See: node_redis for more options on createClient 
       * 
       * @param {string} graphId the graph id
-      * @param {string | RedisClient} [host] Redis host or node_redis client
-      * @param {string | int} [port] Redis port
-      * @param {ClientOpts} [options] node_redis options
+      * @param {string | RedisClient} [host] Redis host or node_redis client or ioredis client
+      * @param {string | number} [port] Redis port (integer)
+      * @param {Object} [options] node_redis options
       */
 	constructor(graphId, host, port, options) {
 		this._graphId = graphId;        // Graph ID
@@ -27,7 +33,7 @@ class Graph {
 		this._relationshipPromise = undefined;  // used as a synchronization mechanizom for relationship types retrival
 
 		this._client =
-			host instanceof redis.RedisClient
+			host && typeof host.send_command === 'function' // check if it's an instance of `redis` or `ioredis`
 				? host
 				: redis.createClient(port, host, options);
 		this._sendCommand = util.promisify(this._client.send_command).bind(this._client);
@@ -55,7 +61,7 @@ class Graph {
 
     /**
      * Transforms a parameter value to string.
-     * @param {object} paramValue 
+     * @param {*} paramValue
      * @returns {string} the string representation of paramValue.
      */
 	paramToString(paramValue) {
@@ -100,7 +106,7 @@ class Graph {
      * @async
 	 * @param {string} query Cypher query
 	 * @param {Map} [params] Parameters map
-	 * @returns {ResultSet} a promise contains a result set
+	 * @returns {Promise<ResultSet>} a promise contains a result set
 	 */
 	async query(query, params) {
 		if (params) {
@@ -118,7 +124,7 @@ class Graph {
 	/**
 	 * Deletes the entire graph
      * @async
-	 * @returns {ResultSet} a promise contains the delete operation running time statistics
+	 * @returns {Promise<ResultSet>} a promise contains the delete operation running time statistics
 	 */
 	async deleteGraph() {
 		var res = await this._sendCommand("graph.DELETE", [this._graphId]);
@@ -135,7 +141,7 @@ class Graph {
 	 * @param {string} procedure Procedure to call
 	 * @param {string[]} [args] Arguments to pass
 	 * @param {string[]} [y] Yield outputs
-	 * @returns {ResultSet} a promise contains the procedure result set data
+	 * @returns {Promise<ResultSet>} a promise contains the procedure result set data
 	 */
 	callProcedure(procedure, args = new Array(), y = new Array()) {
 		let q = "CALL " + procedure + "(" + args.join(",") + ")" + y.join(" ");
@@ -198,7 +204,7 @@ class Graph {
 
 	/**
 	 * Retrieves label by ID.
-	 * @param {int} id internal ID of label.
+	 * @param {number} id internal ID of label. (integer)
 	 * @returns {string} String label.
 	 */
 	getLabel(id) {
@@ -208,8 +214,8 @@ class Graph {
 	/**
 	 * Retrieve all the labels from the graph and returns the wanted label
      * @async
-	 * @param {int} id internal ID of label.
-	 * @returns {string} String label.
+	 * @param {number} id internal ID of label. (integer)
+	 * @returns {Promise<string>} String label.
 	 */
 	async fetchAndGetLabel(id) {
 		await this.labels();
@@ -218,8 +224,8 @@ class Graph {
 
 	/**
 	 * Retrieves relationship type by ID.
-	 * @param {int} id internal ID of relationship type.
-	 * @return String relationship type.
+	 * @param {number} id internal ID of relationship type. (integer)
+	 * @returns {string} relationship type.
 	 */
 	getRelationship(id) {
 		return this._relationshipTypes[id];
@@ -228,8 +234,8 @@ class Graph {
 	/**
 	 * Retrieves al the relationships types from the graph, and returns the wanted type
      * @async
-	 * @param {int} id internal ID of relationship type.
-	 * @returns {string} String relationship type.
+	 * @param {number} id internal ID of relationship type. (integer)
+	 * @returns {Promise<string>} String relationship type.
 	 */
 	async fetchAndGetRelationship(id) {
 		await this.relationshipTypes();
@@ -238,7 +244,7 @@ class Graph {
 
 	/**
 	 * Retrieves property name by ID.
-	 * @param {int} id internal ID of property.
+	 * @param {number} id internal ID of property. (integer)
 	 * @returns {string} String property.
 	 */
 	getProperty(id) {
@@ -247,9 +253,9 @@ class Graph {
 
 	/**
 	 * Retrieves al the properties from the graph, and returns the wanted property
-     * @async
-	 * @param {int} id internal ID of property.
-	 * @returns {string} String property.
+     * @asyncTODO
+	 * @param {number} id internal ID of property. (integer)
+	 * @returns {Promise<string>} String property.
 	 */
 	async fetchAndGetProperty(id) {
 		await this.propertyKeys();
